@@ -6,48 +6,58 @@ from io import (
     IOBase,
     UnsupportedOperation,
 )
+from typing import IO, Generic, Optional, TypeVar, Union, cast
 
 from xz.utils import FloorDict
 
+#
+# Typing note
+#
+# The consensus seems to favour IO instead of IOBase for typing.
+# However we cannot subclass IO[bytes] in IOAbstract as it conflicts with IOBase.
+#
+# As a result, some casting or unions between IOAbstract and IO[bytes] may be required internally.
+#
+
 
 class IOAbstract(IOBase):
-    def __init__(self, length):
+    def __init__(self, length: int) -> None:
         super().__init__()
         self._pos = 0
         self._length = length
         self._modified = False
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return f"<{self.__class__.__name__} object at {hex(hash(self))}>"
 
-    def __len__(self):
+    def __len__(self) -> int:
         return self._length
 
-    def _check_not_closed(self):
+    def _check_not_closed(self) -> None:
         # https://github.com/PyCQA/pylint/issues/3484
         # pylint: disable=using-constant-test
         if self.closed:
             raise ValueError("I/O operation on closed file")
 
-    def fileno(self):
+    def fileno(self) -> int:
         try:
-            return self.fileobj.fileno()
+            return cast(IO[bytes], self.fileobj).fileno()  # type: ignore[attr-defined]
         except AttributeError:
             raise UnsupportedOperation("fileno")  # pylint: disable=raise-missing-from
 
-    def seekable(self):
+    def seekable(self) -> bool:
         """Return a bool indicating whether object supports random access."""
         return True
 
-    def readable(self):
+    def readable(self) -> bool:
         """Return a bool indicating whether object was opened for reading."""
         return True
 
-    def writable(self):
+    def writable(self) -> bool:
         """Return a bool indicating whether object was opened for writing."""
         return True
 
-    def seek(self, pos, whence=SEEK_SET):
+    def seek(self, pos: int, whence: int = SEEK_SET) -> int:
         """Change stream position.
 
         Change the stream position to byte offset pos. Argument pos is
@@ -76,12 +86,12 @@ class IOAbstract(IOBase):
             return self._pos
         raise ValueError("invalid seek position")
 
-    def tell(self):
+    def tell(self) -> int:
         """Return an int indicating the current stream position."""
         self._check_not_closed()
         return self._pos
 
-    def read(self, size=-1):
+    def read(self, size: int = -1) -> bytes:
         """Read at most size bytes, returned as a bytes object.
 
         If the size argument is negative, read until EOF is reached.
@@ -101,17 +111,17 @@ class IOAbstract(IOBase):
             self._pos += len(data)
         return b"".join(parts)
 
-    def _write_start(self):
+    def _write_start(self) -> None:
         if not self._modified:
             self._write_before()
             self._modified = True
 
-    def _write_end(self):
+    def _write_end(self) -> None:
         if self._modified:
             self._write_after()
             self._modified = False
 
-    def write(self, data):
+    def write(self, data: bytes) -> int:
         """Write data, passed as a bytes object.
 
         Returns the number of bytes written, which is always the length
@@ -142,7 +152,7 @@ class IOAbstract(IOBase):
             self._length = max(self._length, self._pos)
         return written_bytes
 
-    def truncate(self, size=None):
+    def truncate(self, size: Optional[int] = None) -> int:
         """Truncate file to size bytes.
         Size defaults to the current IO position as reported by tell().
 
@@ -165,7 +175,7 @@ class IOAbstract(IOBase):
             self._pos = pos  # make sure position is unchanged
         return self._length
 
-    def close(self):
+    def close(self) -> None:
         """Flush and close the stream.
 
         This method has no effect if it is already closed.
@@ -179,7 +189,7 @@ class IOAbstract(IOBase):
     # the methods below are expected to be implemented by subclasses
     # pylint: disable=no-self-use
 
-    def _read(self, size):  # pragma: no cover
+    def _read(self, size: int) -> bytes:  # pragma: no cover
         """Read and return up to size bytes, where size is an int.
 
         The size will not exceed the number of bytes between self._pos and
@@ -190,13 +200,13 @@ class IOAbstract(IOBase):
         """
         raise UnsupportedOperation("read")
 
-    def _write_before(self):
+    def _write_before(self) -> None:
         """This method is called before the first write operation."""
 
-    def _write_after(self):
+    def _write_after(self) -> None:
         """This method is called after the last write operation (usually on file close)."""
 
-    def _write(self, data):  # pragma: no cover
+    def _write(self, data: bytes) -> int:  # pragma: no cover
         """Writes as many bytes from data as possible, and return the number
         of bytes written.
 
@@ -208,7 +218,7 @@ class IOAbstract(IOBase):
         """
         raise UnsupportedOperation("write")
 
-    def _truncate(self, size):  # pragma: no cover
+    def _truncate(self, size: int) -> None:  # pragma: no cover
         """Truncate the file to the given size.
         This resizing can extend or reduce the current file size.
 
@@ -221,51 +231,59 @@ class IOAbstract(IOBase):
 
 
 class IOStatic(IOAbstract):
-    def __init__(self, data):
+    def __init__(self, data: bytes) -> None:
         self.data = bytearray(data)
         super().__init__(len(self.data))
 
-    def writable(self):
+    def writable(self) -> bool:
         return False
 
-    def _read(self, size):
+    def _read(self, size: int) -> bytes:
         return self.data[self._pos : self._pos + size]
 
 
 class IOProxy(IOAbstract):
-    def __init__(self, fileobj, start, end):
+    def __init__(
+        self,
+        fileobj: Union[IO[bytes], IOAbstract],  # see typing note on top of this file
+        start: int,
+        end: int,
+    ) -> None:
         super().__init__(end - start)
         self.fileobj = fileobj
         self.start = start
 
-    def _read(self, size):
+    def _read(self, size: int) -> bytes:
         self.fileobj.seek(self.start + self._pos, SEEK_SET)
         return self.fileobj.read(size)  # size already restricted by caller
 
-    def _write(self, data):
+    def _write(self, data: bytes) -> int:
         self.fileobj.seek(self.start + self._pos, SEEK_SET)
         return self.fileobj.write(data)
 
-    def _truncate(self, size):
+    def _truncate(self, size: int) -> None:
         self.fileobj.truncate(self.start + size)
 
 
-class IOCombiner(IOAbstract):
-    def __init__(self, *fileobjs):
+T = TypeVar("T", bound=IOAbstract)
+
+
+class IOCombiner(IOAbstract, Generic[T]):
+    def __init__(self, *fileobjs: T) -> None:
         super().__init__(0)
-        self._fileobjs = FloorDict()
+        self._fileobjs: FloorDict[T] = FloorDict()
         for fileobj in fileobjs:
             self._append(fileobj)
 
-    def _get_fileobj(self):
-        start, fileobj = self._fileobjs[self._pos, True]
+    def _get_fileobj(self) -> T:
+        start, fileobj = self._fileobjs.get_with_index(self._pos)
         fileobj.seek(self._pos - start, SEEK_SET)
         return fileobj
 
-    def _read(self, size):
+    def _read(self, size: int) -> bytes:
         return self._get_fileobj().read(size)
 
-    def _write_after(self):
+    def _write_after(self) -> None:
         if self._fileobjs:
             last_fileobj = self._fileobjs.last_item
             if last_fileobj:
@@ -273,9 +291,9 @@ class IOCombiner(IOAbstract):
             else:
                 del self._fileobjs[self._fileobjs.last_key]
 
-    def _write(self, data):
+    def _write(self, data: bytes) -> int:
         if self._fileobjs:
-            fileobj = self._get_fileobj()
+            fileobj: Optional[T] = self._get_fileobj()
         else:
             fileobj = None
 
@@ -287,8 +305,8 @@ class IOCombiner(IOAbstract):
         # otherwire this will raise UnsupportedOperation
         return fileobj.write(data)
 
-    def _truncate(self, size):
-        start, fileobj = self._fileobjs[size, True]
+    def _truncate(self, size: int) -> None:
+        start, fileobj = self._fileobjs.get_with_index(size)
         if start != size:
             fileobj.truncate(size - start)
         for key in reversed(self._fileobjs):
@@ -296,13 +314,13 @@ class IOCombiner(IOAbstract):
                 break
             del self._fileobjs[key]
 
-    def _append(self, fileobj):
+    def _append(self, fileobj: T) -> None:
         if not isinstance(fileobj, IOAbstract):
             raise TypeError
         self._fileobjs[self._length] = fileobj  # override empty streams
         self._length += len(fileobj)
 
-    def _change_fileobj(self):
+    def _change_fileobj(self) -> None:
         """Create and append a new fileobj.
 
         If the last fileobj was empty, delete it.
@@ -319,7 +337,7 @@ class IOCombiner(IOAbstract):
         # create and append new fileobj
         self._append(self._create_fileobj())
 
-    def _create_fileobj(self):  # pragma: no cover
+    def _create_fileobj(self) -> T:  # pragma: no cover
         """
         Create a new fileobj to be concatenated.
 
