@@ -2,6 +2,7 @@ import doctest
 import os
 from pathlib import Path
 import shutil
+from typing import Iterator, List, Optional, Tuple
 
 import pytest
 
@@ -9,7 +10,7 @@ import xz
 
 
 @pytest.fixture(autouse=True)
-def change_dir(tmp_path):
+def change_dir(tmp_path: Path) -> Iterator[None]:
     old_dir = os.getcwd()
     shutil.copy(Path(__file__).parent / "files" / "example.xz", tmp_path)
     os.chdir(tmp_path)
@@ -17,10 +18,10 @@ def change_dir(tmp_path):
     os.chdir(old_dir)
 
 
-def _parse_readme():
+def _parse_readme() -> List[Tuple[int, str]]:
     code_blocks = []
     current_code_block = ""
-    current_code_block_line = None
+    current_code_block_line: Optional[int] = None
     with (Path(__file__).parent.parent.parent / "README.md").open() as fin:
         for line_no, line in enumerate(fin):
             if line.startswith("```"):
@@ -39,22 +40,20 @@ def _parse_readme():
 _README_CODE_BLOCKS = _parse_readme()
 
 
-@pytest.fixture(
-    params=[
+@pytest.mark.parametrize(
+    "code_block",
+    [
         pytest.param(code_block, id=f"line_{line_no}")
         for line_no, code_block in _README_CODE_BLOCKS
-    ]
+    ],
 )
-def readme_block_path(request, tmp_path):
+def test_readme(
+    code_block: str, tmp_path: Path
+) -> None:  # pylint: disable=redefined-outer-name
     path = tmp_path / "block.txt"
-    path.write_text(request.param)
-    yield path
-    path.unlink()
-
-
-def test_readme(readme_block_path):  # pylint: disable=redefined-outer-name
+    path.write_text(code_block)
     failure_count, test_count = doctest.testfile(
-        readme_block_path,
+        str(path),
         module_relative=False,
         extraglobs={"xz": xz},
     )
